# Image transforms (filters and masks)

## Filters

??? abstract "`cryojax.ndimage.transforms.AbstractFilter`"
    ::: cryojax.ndimage.transforms.AbstractFilter
        options:
            members:
                - get


## Masks

??? abstract "`cryojax.ndimage.transforms.AbstractMask`"
    ::: cryojax.ndimage.transforms.AbstractMask
        options:
            members:
                - get

::: cryojax.ndimage.transforms.InverseSincMask
        options:
            members:
                - __init__
                - get
                - __call__
